==> psi-plugins-debug-1.5-3-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/qipxstatusesplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/psi-plugins/src/plugins-1.5/generic/qipxstatusesplugin/qipxstatuses.png
  0x0,0x0,0x2,0x29,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x1,0xf0,0x49,0x44,0x41,0x54,0x78,0xda,0x63,0x60,0x40,0x2,0x1e,0xbe,
  0x51,0x25,0x75,0xcd,0x13,0xff,0x83,0x68,0x6,0x72,0x0,0x48,0xf3,0xc5,0x4b,0x57,
  0xff,0x83,0x68,0x20,0xd7,0x14,0x88,0x95,0x81,0x58,0x80,0x68,0x3,0x6a,0x1b,0xfb,
  0xde,0x34,0xb6,0x4d,0xf9,0x3f,0x65,0xe6,0x62,0x30,0x6,0x19,0x84,0x8c,0x33,0x72,
  0x6b,0x37,0x3,0x95,0xa9,0xe0,0x34,0xc0,0xd5,0x27,0xba,0xc,0x64,0x0,0x32,0xf8,
  0xf3,0xe7,0xf,0x18,0x7f,0xfe,0xfc,0xf9,0x7f,0x51,0x45,0x3b,0xc8,0x65,0xe6,0xf8,
  0x1c,0x61,0xa,0x33,0xa0,0xee,0x44,0xee,0xff,0xc8,0xb3,0x4a,0xff,0x3d,0x8e,0x89,
  0xfc,0x77,0xdd,0x2e,0xf7,0xff,0xed,0xdb,0xb7,0x30,0x3,0x4c,0xf1,0x19,0x20,0x7,
  0x33,0x60,0xe3,0xef,0xea,0xff,0xe1,0x3f,0x19,0xfe,0xfb,0x3e,0x67,0xf8,0x6f,0x34,
  0x97,0x11,0xd9,0x0,0x65,0x7c,0x6,0x88,0xc1,0xc,0x70,0x3c,0xce,0xf0,0xdf,0x7c,
  0x37,0xc3,0x7f,0x83,0x39,0x8c,0xff,0xd,0x26,0x31,0xfe,0x7f,0xf2,0xe4,0xc9,0xff,
  0xac,0xfc,0xba,0xff,0x84,0x2,0x95,0x7,0x64,0x0,0xc8,0xcf,0x93,0x4e,0x57,0xff,
  0xf7,0x58,0x26,0x5,0xd6,0x5c,0x74,0xc4,0xf3,0xff,0xbd,0x7b,0xf7,0xfe,0x27,0x67,
  0x94,0x61,0x1a,0xe0,0xe6,0x15,0x55,0x3,0xd2,0x4,0xc3,0xb3,0xe7,0xaf,0xfc,0x7f,
  0xf6,0xec,0x45,0x70,0xa0,0xbd,0x7b,0xf7,0xee,0xff,0xab,0x57,0xaf,0xfe,0x3f,0x7e,
  0xfc,0xf8,0xff,0xc9,0xd3,0xe7,0xc0,0x31,0x83,0xac,0xd6,0xd1,0x25,0xa4,0x8d,0x1,
  0xe4,0x2f,0x64,0xb0,0x73,0xf7,0xc1,0xff,0x9b,0xb6,0xec,0xfe,0x5f,0x76,0xd9,0xb,
  0x1c,0x88,0x76,0xa7,0x18,0xfe,0x47,0x6e,0xb7,0xfa,0xbf,0x71,0xf3,0xae,0xff,0x7b,
  0xf6,0x1e,0x46,0x51,0xb,0x76,0x11,0xc8,0x0,0x50,0xe2,0xf1,0xf4,0x8b,0x6,0xc5,
  0xb1,0x1b,0x48,0xa2,0xb3,0x7f,0xf6,0xff,0xdd,0xd7,0x37,0xfd,0xf,0xf9,0x4,0xc,
  0xc4,0x17,0xc,0xff,0x97,0x1c,0x9c,0xfd,0xbf,0xb5,0x6b,0x1a,0x58,0x13,0x4c,0x1d,
  0x48,0xf,0xd8,0x0,0x50,0xb2,0x5d,0xbe,0x6a,0x13,0x38,0x94,0x41,0xfe,0x4,0xe1,
  0xaa,0xfa,0x3e,0x30,0xdf,0xf9,0x12,0xc3,0x7f,0xc3,0x15,0xc,0xff,0xf7,0xef,0xdf,
  0xf,0x8e,0x1,0x98,0x9a,0xb3,0x67,0xcf,0xfe,0x7,0xe9,0xb1,0xb2,0x75,0xef,0x4,
  0x5,0x83,0x88,0x6f,0x50,0xdc,0x5a,0x90,0x2,0x10,0x6,0x49,0x96,0xd7,0x76,0xff,
  0x7f,0xf9,0xf2,0xe5,0x7f,0xb3,0x8d,0xc,0xe0,0x40,0x84,0x19,0x0,0x92,0x3,0xd9,
  0xa,0xc2,0x50,0x97,0xa8,0x21,0x87,0xa7,0x8,0x48,0x11,0x48,0x71,0x49,0x55,0x27,
  0x38,0xda,0x40,0x9a,0x41,0x78,0xdd,0x86,0x8d,0xff,0x61,0x72,0xd0,0x98,0x70,0xc5,
  0x9a,0xa4,0x83,0x23,0xd2,0x33,0x60,0x2e,0xd9,0xb9,0x6b,0xef,0xff,0xad,0xdb,0xb6,
  0xff,0xdf,0xb4,0x79,0xeb,0xff,0x85,0x8b,0x97,0xc1,0x6d,0x86,0xe6,0x54,0x15,0x7c,
  0x69,0x41,0x24,0x26,0xa9,0x70,0x2a,0x4c,0x3,0xc,0x83,0xc4,0xa0,0xc9,0x58,0x5,
  0x39,0x2d,0x0,0x0,0xfa,0x6e,0xb4,0x87,0x54,0xa5,0x17,0x49,0x0,0x0,0x0,0x0,
  0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // qipxstatuses.png
  0x0,0x10,
  0x6,0x91,0x41,0x27,
  0x0,0x71,
  0x0,0x69,0x0,0x70,0x0,0x78,0x0,0x73,0x0,0x74,0x0,0x61,0x0,0x74,0x0,0x75,0x0,0x73,0x0,0x65,0x0,0x73,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons/qipxstatuses.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}

==> psi-plugins-debug-1.5-3.1-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/qipxstatusesplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/plugins-1.5/generic/qipxstatusesplugin/qipxstatuses.png
  0x0,0x0,0x2,0x29,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x1,0xf0,0x49,0x44,0x41,0x54,0x78,0xda,0x63,0x60,0x40,0x2,0x1e,0xbe,
  0x51,0x25,0x75,0xcd,0x13,0xff,0x83,0x68,0x6,0x72,0x0,0x48,0xf3,0xc5,0x4b,0x57,
  0xff,0x83,0x68,0x20,0xd7,0x14,0x88,0x95,0x81,0x58,0x80,0x68,0x3,0x6a,0x1b,0xfb,
  0xde,0x34,0xb6,0x4d,0xf9,0x3f,0x65,0xe6,0x62,0x30,0x6,0x19,0x84,0x8c,0x33,0x72,
  0x6b,0x37,0x3,0x95,0xa9,0xe0,0x34,0xc0,0xd5,0x27,0xba,0xc,0x64,0x0,0x32,0xf8,
  0xf3,0xe7,0xf,0x18,0x7f,0xfe,0xfc,0xf9,0x7f,0x51,0x45,0x3b,0xc8,0x65,0xe6,0xf8,
  0x1c,0x61,0xa,0x33,0xa0,0xee,0x44,0xee,0xff,0xc8,0xb3,0x4a,0xff,0x3d,0x8e,0x89,
  0xfc,0x77,0xdd,0x2e,0xf7,0xff,0xed,0xdb,0xb7,0x30,0x3,0x4c,0xf1,0x19,0x20,0x7,
  0x33,0x60,0xe3,0xef,0xea,0xff,0xe1,0x3f,0x19,0xfe,0xfb,0x3e,0x67,0xf8,0x6f,0x34,
  0x97,0x11,0xd9,0x0,0x65,0x7c,0x6,0x88,0xc1,0xc,0x70,0x3c,0xce,0xf0,0xdf,0x7c,
  0x37,0xc3,0x7f,0x83,0x39,0x8c,0xff,0xd,0x26,0x31,0xfe,0x7f,0xf2,0xe4,0xc9,0xff,
  0xac,0xfc,0xba,0xff,0x84,0x2,0x95,0x7,0x64,0x0,0xc8,0xcf,0x93,0x4e,0x57,0xff,
  0xf7,0x58,0x26,0x5,0xd6,0x5c,0x74,0xc4,0xf3,0xff,0xbd,0x7b,0xf7,0xfe,0x27,0x67,
  0x94,0x61,0x1a,0xe0,0xe6,0x15,0x55,0x3,0xd2,0x4,0xc3,0xb3,0xe7,0xaf,0xfc,0x7f,
  0xf6,0xec,0x45,0x70,0xa0,0xbd,0x7b,0xf7,0xee,0xff,0xab,0x57,0xaf,0xfe,0x3f,0x7e,
  0xfc,0xf8,0xff,0xc9,0xd3,0xe7,0xc0,0x31,0x83,0xac,0xd6,0xd1,0x25,0xa4,0x8d,0x1,
  0xe4,0x2f,0x64,0xb0,0x73,0xf7,0xc1,0xff,0x9b,0xb6,0xec,0xfe,0x5f,0x76,0xd9,0xb,
  0x1c,0x88,0x76,0xa7,0x18,0xfe,0x47,0x6e,0xb7,0xfa,0xbf,0x71,0xf3,0xae,0xff,0x7b,
  0xf6,0x1e,0x46,0x51,0xb,0x76,0x11,0xc8,0x0,0x50,0xe2,0xf1,0xf4,0x8b,0x6,0xc5,
  0xb1,0x1b,0x48,0xa2,0xb3,0x7f,0xf6,0xff,0xdd,0xd7,0x37,0xfd,0xf,0xf9,0x4,0xc,
  0xc4,0x17,0xc,0xff,0x97,0x1c,0x9c,0xfd,0xbf,0xb5,0x6b,0x1a,0x58,0x13,0x4c,0x1d,
  0x48,0xf,0xd8,0x0,0x50,0xb2,0x5d,0xbe,0x6a,0x13,0x38,0x94,0x41,0xfe,0x4,0xe1,
  0xaa,0xfa,0x3e,0x30,0xdf,0xf9,0x12,0xc3,0x7f,0xc3,0x15,0xc,0xff,0xf7,0xef,0xdf,
  0xf,0x8e,0x1,0x98,0x9a,0xb3,0x67,0xcf,0xfe,0x7,0xe9,0xb1,0xb2,0x75,0xef,0x4,
  0x5,0x83,0x88,0x6f,0x50,0xdc,0x5a,0x90,0x2,0x10,0x6,0x49,0x96,0xd7,0x76,0xff,
  0x7f,0xf9,0xf2,0xe5,0x7f,0xb3,0x8d,0xc,0xe0,0x40,0x84,0x19,0x0,0x92,0x3,0xd9,
  0xa,0xc2,0x50,0x97,0xa8,0x21,0x87,0xa7,0x8,0x48,0x11,0x48,0x71,0x49,0x55,0x27,
  0x38,0xda,0x40,0x9a,0x41,0x78,0xdd,0x86,0x8d,0xff,0x61,0x72,0xd0,0x98,0x70,0xc5,
  0x9a,0xa4,0x83,0x23,0xd2,0x33,0x60,0x2e,0xd9,0xb9,0x6b,0xef,0xff,0xad,0xdb,0xb6,
  0xff,0xdf,0xb4,0x79,0xeb,0xff,0x85,0x8b,0x97,0xc1,0x6d,0x86,0xe6,0x54,0x15,0x7c,
  0x69,0x41,0x24,0x26,0xa9,0x70,0x2a,0x4c,0x3,0xc,0x83,0xc4,0xa0,0xc9,0x58,0x5,
  0x39,0x2d,0x0,0x0,0xfa,0x6e,0xb4,0x87,0x54,0xa5,0x17,0x49,0x0,0x0,0x0,0x0,
  0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // qipxstatuses.png
  0x0,0x10,
  0x6,0x91,0x41,0x27,
  0x0,0x71,
  0x0,0x69,0x0,0x70,0x0,0x78,0x0,0x73,0x0,0x74,0x0,0x61,0x0,0x74,0x0,0x75,0x0,0x73,0x0,0x65,0x0,0x73,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x19,0x36,0x8,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x19,0x36,0x8,
  // :/icons/qipxstatuses.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x19,0x36,0x8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}
